[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] Renames:



ChangeSet 1.1391, 2005/04/28 15:04:13+01:00, kaf24@xxxxxxxxxxxxxxxxxxxx

        Renames:
         execution_context/xen_regs -> cpu_user_regs
         full_execution_context     -> vcpu_guest_context
        [defined both 'struct xxx' and 'xxx_t' forms]
        Signed-off-by: Keir Fraser <keir@xxxxxxxxxxxxx>



 linux-2.6.11-xen-sparse/arch/xen/i386/kernel/smpboot.c         |   20 -
 linux-2.6.11-xen-sparse/include/asm-xen/asm-i386/hypercall.h   |    2 
 linux-2.6.11-xen-sparse/include/asm-xen/asm-x86_64/hypercall.h |    2 
 tools/libxc/xc.h                                               |    2 
 tools/libxc/xc_domain.c                                        |    2 
 tools/libxc/xc_linux_build.c                                   |   24 -
 tools/libxc/xc_linux_restore.c                                 |    8 
 tools/libxc/xc_linux_save.c                                    |   10 
 tools/libxc/xc_plan9_build.c                                   |   28 -
 tools/libxc/xc_ptrace.c                                        |   14 
 tools/libxc/xc_vmx_build.c                                     |   34 +-
 tools/xentrace/xenctx.c                                        |   37 +-
 xen/arch/ia64/dom0_ops.c                                       |    2 
 xen/arch/ia64/domain.c                                         |    4 
 xen/arch/ia64/xenmisc.c                                        |    2 
 xen/arch/x86/apic.c                                            |    6 
 xen/arch/x86/cdb.c                                             |    6 
 xen/arch/x86/dom0_ops.c                                        |   18 -
 xen/arch/x86/domain.c                                          |  166 
+++++-----
 xen/arch/x86/extable.c                                         |    2 
 xen/arch/x86/irq.c                                             |    4 
 xen/arch/x86/mm.c                                              |    2 
 xen/arch/x86/nmi.c                                             |    2 
 xen/arch/x86/shadow.c                                          |    2 
 xen/arch/x86/time.c                                            |    2 
 xen/arch/x86/traps.c                                           |   34 +-
 xen/arch/x86/vmx.c                                             |   42 +-
 xen/arch/x86/vmx_intercept.c                                   |   10 
 xen/arch/x86/vmx_io.c                                          |   36 +-
 xen/arch/x86/vmx_platform.c                                    |   14 
 xen/arch/x86/vmx_vmcs.c                                        |   48 +-
 xen/arch/x86/x86_32/asm-offsets.c                              |   40 +-
 xen/arch/x86/x86_32/call_with_regs.S                           |   52 +--
 xen/arch/x86/x86_32/entry.S                                    |  150 ++++-----
 xen/arch/x86/x86_32/seg_fixup.c                                |    2 
 xen/arch/x86/x86_32/traps.c                                    |   13 
 xen/arch/x86/x86_64/asm-offsets.c                              |   48 +-
 xen/arch/x86/x86_64/entry.S                                    |   58 +--
 xen/arch/x86/x86_64/mm.c                                       |    6 
 xen/arch/x86/x86_64/traps.c                                    |   11 
 xen/arch/x86/x86_emulate.c                                     |    6 
 xen/common/dom0_ops.c                                          |    6 
 xen/common/domain.c                                            |   10 
 xen/common/keyhandler.c                                        |   17 -
 xen/drivers/char/console.c                                     |    4 
 xen/drivers/char/serial.c                                      |    4 
 xen/include/asm-ia64/debugger.h                                |    4 
 xen/include/asm-ia64/domain.h                                  |    2 
 xen/include/asm-ia64/regs.h                                    |    2 
 xen/include/asm-x86/apic.h                                     |    4 
 xen/include/asm-x86/debugger.h                                 |   12 
 xen/include/asm-x86/domain.h                                   |    2 
 xen/include/asm-x86/processor.h                                |   10 
 xen/include/asm-x86/shadow.h                                   |    2 
 xen/include/asm-x86/vmx.h                                      |    2 
 xen/include/asm-x86/vmx_platform.h                             |    4 
 xen/include/asm-x86/vmx_vmcs.h                                 |    4 
 xen/include/asm-x86/x86_32/asm_defns.h                         |   26 -
 xen/include/asm-x86/x86_32/current.h                           |   12 
 xen/include/asm-x86/x86_32/regs.h                              |    2 
 xen/include/asm-x86/x86_64/asm_defns.h                         |    2 
 xen/include/asm-x86/x86_64/current.h                           |   12 
 xen/include/asm-x86/x86_64/regs.h                              |    2 
 xen/include/asm-x86/x86_emulate.h                              |    6 
 xen/include/public/arch-ia64.h                                 |    6 
 xen/include/public/arch-x86_32.h                               |   13 
 xen/include/public/arch-x86_64.h                               |   13 
 xen/include/public/dom0_ops.h                                  |    4 
 xen/include/xen/domain.h                                       |    2 
 xen/include/xen/irq.h                                          |    4 
 xen/include/xen/keyhandler.h                                   |    4 
 xen/include/xen/serial.h                                       |    2 
 72 files changed, 587 insertions(+), 583 deletions(-)


diff -Nru a/linux-2.6.11-xen-sparse/arch/xen/i386/kernel/smpboot.c 
b/linux-2.6.11-xen-sparse/arch/xen/i386/kernel/smpboot.c
--- a/linux-2.6.11-xen-sparse/arch/xen/i386/kernel/smpboot.c    2005-04-28 
11:03:31 -04:00
+++ b/linux-2.6.11-xen-sparse/arch/xen/i386/kernel/smpboot.c    2005-04-28 
11:03:31 -04:00
@@ -820,7 +820,7 @@
 #if 0
        unsigned short nmi_high = 0, nmi_low = 0;
 #endif
-       full_execution_context_t ctxt;
+       vcpu_guest_context_t ctxt;
        extern void startup_32_smp(void);
        extern void hypervisor_callback(void);
        extern void failsafe_callback(void);
@@ -865,15 +865,15 @@
 
        memset(&ctxt, 0, sizeof(ctxt));
 
-       ctxt.cpu_ctxt.ds = __USER_DS;
-       ctxt.cpu_ctxt.es = __USER_DS;
-       ctxt.cpu_ctxt.fs = 0;
-       ctxt.cpu_ctxt.gs = 0;
-       ctxt.cpu_ctxt.ss = __KERNEL_DS;
-       ctxt.cpu_ctxt.cs = __KERNEL_CS;
-       ctxt.cpu_ctxt.eip = start_eip;
-       ctxt.cpu_ctxt.esp = idle->thread.esp;
-       ctxt.cpu_ctxt.eflags = (1<<9) | (1<<2) | (idle->thread.io_pl<<12);
+       ctxt.user_regs.ds = __USER_DS;
+       ctxt.user_regs.es = __USER_DS;
+       ctxt.user_regs.fs = 0;
+       ctxt.user_regs.gs = 0;
+       ctxt.user_regs.ss = __KERNEL_DS;
+       ctxt.user_regs.cs = __KERNEL_CS;
+       ctxt.user_regs.eip = start_eip;
+       ctxt.user_regs.esp = idle->thread.esp;
+       ctxt.user_regs.eflags = (1<<9) | (1<<2) | (idle->thread.io_pl<<12);
 
        /* FPU is set up to default initial state. */
        memset(ctxt.fpu_ctxt, 0, sizeof(ctxt.fpu_ctxt));
diff -Nru a/linux-2.6.11-xen-sparse/include/asm-xen/asm-i386/hypercall.h 
b/linux-2.6.11-xen-sparse/include/asm-xen/asm-i386/hypercall.h
--- a/linux-2.6.11-xen-sparse/include/asm-xen/asm-i386/hypercall.h      
2005-04-28 11:03:32 -04:00
+++ b/linux-2.6.11-xen-sparse/include/asm-xen/asm-i386/hypercall.h      
2005-04-28 11:03:32 -04:00
@@ -519,7 +519,7 @@
 
 static inline int
 HYPERVISOR_boot_vcpu(
-    unsigned long vcpu, full_execution_context_t *ctxt)
+    unsigned long vcpu, vcpu_guest_context_t *ctxt)
 {
     int ret;
     unsigned long ign1, ign2;
diff -Nru a/linux-2.6.11-xen-sparse/include/asm-xen/asm-x86_64/hypercall.h 
b/linux-2.6.11-xen-sparse/include/asm-xen/asm-x86_64/hypercall.h
--- a/linux-2.6.11-xen-sparse/include/asm-xen/asm-x86_64/hypercall.h    
2005-04-28 11:03:32 -04:00
+++ b/linux-2.6.11-xen-sparse/include/asm-xen/asm-x86_64/hypercall.h    
2005-04-28 11:03:32 -04:00
@@ -489,7 +489,7 @@
 
 static inline int
 HYPERVISOR_boot_vcpu(
-    unsigned long vcpu, full_execution_context_t *ctxt)
+    unsigned long vcpu, vcpu_guest_context_t *ctxt)
 {
     int ret;
 
diff -Nru a/tools/libxc/xc.h b/tools/libxc/xc.h
--- a/tools/libxc/xc.h  2005-04-28 11:03:32 -04:00
+++ b/tools/libxc/xc.h  2005-04-28 11:03:32 -04:00
@@ -160,7 +160,7 @@
                           u32 domid,
                           u32 vcpu,
                           xc_domaininfo_t *info,
-                          full_execution_context_t *ctxt);
+                          vcpu_guest_context_t *ctxt);
 int xc_domain_setcpuweight(int xc_handle,
                            u32 domid,
                            float weight);
diff -Nru a/tools/libxc/xc_domain.c b/tools/libxc/xc_domain.c
--- a/tools/libxc/xc_domain.c   2005-04-28 11:03:33 -04:00
+++ b/tools/libxc/xc_domain.c   2005-04-28 11:03:33 -04:00
@@ -144,7 +144,7 @@
                           u32 domid,
                           u32 vcpu,
                           xc_domaininfo_t *info,
-                          full_execution_context_t *ctxt)
+                          vcpu_guest_context_t *ctxt)
 {
     int rc, errno_saved;
     dom0_op_t op;
diff -Nru a/tools/libxc/xc_linux_build.c b/tools/libxc/xc_linux_build.c
--- a/tools/libxc/xc_linux_build.c      2005-04-28 11:03:32 -04:00
+++ b/tools/libxc/xc_linux_build.c      2005-04-28 11:03:32 -04:00
@@ -45,7 +45,7 @@
                          gzFile initrd_gfd, unsigned long initrd_len,
                          unsigned long nr_pages,
                          unsigned long *pvsi, unsigned long *pvke,
-                         full_execution_context_t *ctxt,
+                         vcpu_guest_context_t *ctxt,
                          const char *cmdline,
                          unsigned long shared_info_frame,
                          unsigned int control_evtchn,
@@ -316,7 +316,7 @@
     int initrd_fd = -1;
     gzFile initrd_gfd = NULL;
     int rc, i;
-    full_execution_context_t st_ctxt, *ctxt = &st_ctxt;
+    vcpu_guest_context_t st_ctxt, *ctxt = &st_ctxt;
     unsigned long nr_pages;
     char         *image = NULL;
     unsigned long image_size, initrd_size=0;
@@ -400,16 +400,16 @@
      *  [EAX,EBX,ECX,EDX,EDI,EBP are zero]
      *       EFLAGS = IF | 2 (bit 1 is reserved and should always be 1)
      */
-    ctxt->cpu_ctxt.ds = FLAT_KERNEL_DS;
-    ctxt->cpu_ctxt.es = FLAT_KERNEL_DS;
-    ctxt->cpu_ctxt.fs = FLAT_KERNEL_DS;
-    ctxt->cpu_ctxt.gs = FLAT_KERNEL_DS;
-    ctxt->cpu_ctxt.ss = FLAT_KERNEL_DS;
-    ctxt->cpu_ctxt.cs = FLAT_KERNEL_CS;
-    ctxt->cpu_ctxt.eip = vkern_entry;
-    ctxt->cpu_ctxt.esp = vstartinfo_start + 2*PAGE_SIZE;
-    ctxt->cpu_ctxt.esi = vstartinfo_start;
-    ctxt->cpu_ctxt.eflags = (1<<9) | (1<<2);
+    ctxt->user_regs.ds = FLAT_KERNEL_DS;
+    ctxt->user_regs.es = FLAT_KERNEL_DS;
+    ctxt->user_regs.fs = FLAT_KERNEL_DS;
+    ctxt->user_regs.gs = FLAT_KERNEL_DS;
+    ctxt->user_regs.ss = FLAT_KERNEL_DS;
+    ctxt->user_regs.cs = FLAT_KERNEL_CS;
+    ctxt->user_regs.eip = vkern_entry;
+    ctxt->user_regs.esp = vstartinfo_start + 2*PAGE_SIZE;
+    ctxt->user_regs.esi = vstartinfo_start;
+    ctxt->user_regs.eflags = (1<<9) | (1<<2);
 
     /* FPU is set up to default initial state. */
     memset(ctxt->fpu_ctxt, 0, sizeof(ctxt->fpu_ctxt));
diff -Nru a/tools/libxc/xc_linux_save.c b/tools/libxc/xc_linux_save.c
--- a/tools/libxc/xc_linux_save.c       2005-04-28 11:03:32 -04:00
+++ b/tools/libxc/xc_linux_save.c       2005-04-28 11:03:32 -04:00
@@ -325,7 +325,7 @@
 
 int suspend_and_state(int xc_handle, XcIOContext *ioctxt,                    
                       xc_domaininfo_t *info,
-                      full_execution_context_t *ctxt)
+                      vcpu_guest_context_t *ctxt)
 {
     int i=0;
     
@@ -391,7 +391,7 @@
     unsigned long shared_info_frame;
     
     /* A copy of the CPU context of the guest. */
-    full_execution_context_t ctxt;
+    vcpu_guest_context_t ctxt;
 
     /* A table containg the type of each PFN (/not/ MFN!). */
     unsigned long *pfn_type = NULL;
@@ -922,7 +922,7 @@
                           "SUSPEND flags %08u shinfo %08lx eip %08u "
                           "esi %08u\n",info.flags,
                           info.shared_info_frame,
-                          ctxt.cpu_ctxt.eip, ctxt.cpu_ctxt.esi );
+                          ctxt.user_regs.eip, ctxt.user_regs.esi );
             } 
 
             if ( xc_shadow_control( xc_handle, domid, 
@@ -995,7 +995,7 @@
        domid for this to succeed. */
     p_srec = xc_map_foreign_range(xc_handle, domid,
                                    sizeof(*p_srec), PROT_READ, 
-                                   ctxt.cpu_ctxt.esi);
+                                   ctxt.user_regs.esi);
     if (!p_srec){
         xcio_error(ioctxt, "Couldn't map suspend record");
         goto out;
@@ -1009,7 +1009,7 @@
     }
 
     /* Canonicalise the suspend-record frame number. */
-    if ( !translate_mfn_to_pfn(&ctxt.cpu_ctxt.esi) ){
+    if ( !translate_mfn_to_pfn(&ctxt.user_regs.esi) ){
         xcio_error(ioctxt, "Suspend record is not in range of pseudophys map");
         goto out;
     }
diff -Nru a/tools/libxc/xc_plan9_build.c b/tools/libxc/xc_plan9_build.c
--- a/tools/libxc/xc_plan9_build.c      2005-04-28 11:03:33 -04:00
+++ b/tools/libxc/xc_plan9_build.c      2005-04-28 11:03:33 -04:00
@@ -113,7 +113,7 @@
              unsigned long tot_pages,
              unsigned long *virt_startinfo_addr,
              unsigned long *virt_load_addr,
-             full_execution_context_t * ctxt,
+             vcpu_guest_context_t * ctxt,
              const char *cmdline,
              unsigned long shared_info_frame, 
              unsigned int control_evtchn,
@@ -411,7 +411,7 @@
        int kernel_fd = -1;
        gzFile kernel_gfd = NULL;
        int rc, i;
-       full_execution_context_t st_ctxt, *ctxt = &st_ctxt;
+       vcpu_guest_context_t st_ctxt, *ctxt = &st_ctxt;
        unsigned long virt_startinfo_addr;
 
        if ((tot_pages = xc_get_tot_pages(xc_handle, domid)) < 0) {
@@ -482,20 +482,20 @@
         *  [EAX,EBX,ECX,EDX,EDI,EBP are zero]
         *       EFLAGS = IF | 2 (bit 1 is reserved and should always be 1)
         */
-       ctxt->cpu_ctxt.ds = FLAT_KERNEL_DS;
-       ctxt->cpu_ctxt.es = FLAT_KERNEL_DS;
-       ctxt->cpu_ctxt.fs = FLAT_KERNEL_DS;
-       ctxt->cpu_ctxt.gs = FLAT_KERNEL_DS;
-       ctxt->cpu_ctxt.ss = FLAT_KERNEL_DS;
-       ctxt->cpu_ctxt.cs = FLAT_KERNEL_CS;
-       ctxt->cpu_ctxt.eip = load_addr;

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.
diff -Nru a/tools/libxc/xc_linux_restore.c b/tools/libxc/xc_linux_restore.c
--- a/tools/libxc/xc_linux_restore.c    2005-04-28 11:03:33 -04:00
+++ b/tools/libxc/xc_linux_restore.c    2005-04-28 11:03:33 -04:00
@@ -73,7 +73,7 @@
     shared_info_t *shared_info = (shared_info_t *)shared_info_page;
     
     /* A copy of the CPU context of the guest. */
-    full_execution_context_t ctxt;
+    vcpu_guest_context_t ctxt;
 
     /* First 16 bytes of the state file must contain 'LinuxGuestRecord'. */
     char signature[16];
@@ -505,13 +505,13 @@
     }
 
     /* Uncanonicalise the suspend-record frame number and poke resume rec. */
-    pfn = ctxt.cpu_ctxt.esi;
+    pfn = ctxt.user_regs.esi;
     if ( (pfn >= nr_pfns) || (pfn_type[pfn] != NOTAB) )
     {
         xcio_error(ioctxt, "Suspend record frame number is bad");
         goto out;
     }
-    ctxt.cpu_ctxt.esi = mfn = pfn_to_mfn_table[pfn];
+    ctxt.user_regs.esi = mfn = pfn_to_mfn_table[pfn];
     p_srec = xc_map_foreign_range(
         xc_handle, dom, PAGE_SIZE, PROT_WRITE, mfn);
     p_srec->resume_info.nr_pages    = nr_pfns;
@@ -599,7 +599,7 @@
 
     /*
      * Safety checking of saved context:
      *  1. cpu_ctxt is fine, as Xen checks that on context switch.
      *  2. fpu_ctxt is fine, as it can't hurt Xen.
      *  3. trap_ctxt needs the code selectors checked.
      *  4. fast_trap_idx is checked by Xen.
@@ -599,7 +599,7 @@
     /*
      * Safety checking of saved context:
-     *  1. cpu_ctxt is fine, as Xen checks that on context switch.
+     *  1. user_regs is fine, as Xen checks that on context switch.
      *  2. fpu_ctxt is fine, as it can't hurt Xen.
      *  3. trap_ctxt needs the code selectors checked.